@@ -1,4 +1,5 @@
 from .core import (LoginView, SetupView, BackupTokensView, PhoneSetupView,
-                   PhoneSetupView, PhoneDeleteView, SetupCompleteView)
+                   PhoneDeleteView, SetupCompleteView)
+from .mixins import OTPRequiredMixin
 from .profile import ProfileView, DisableView
 from .twilio import TwilioCallApp
